@@ -3,6 +3,7 @@ import os
 import json
 import pandas as pd
 import subprocess
+import pyperclip
 
 def get_command(n_lines: list):
     # TODO: propagate that last line in n_lines is the # of lines used
@@ -21,13 +22,15 @@ def run_command_from_alias(alias: str):
     df = pd.DataFrame(config)
     df.columns = ['Name','Time','Command']
     
-    cmd_to_run = df[df['Name'] == alias]['Command'].values[0]
-    cmd_to_run = " && ".join(cmd_to_run)
+    list_to_run = df[df['Name'] == alias]['Command'].values[0]
+    cmd_to_run = " && ".join(list_to_run)
     
     # TODO: maybe replace with this fix for source
     # https://stackoverflow.com/questions/7040592/calling-the-source-command-from-subprocess-popen
-    print(f"Running {cmd_to_run}")
-    subprocess.Popen(cmd_to_run, shell=True)
+    print(f"Copied {cmd_to_run} to clipboard")
+    pyperclip.copy(cmd_to_run)
+    # Maybe we can use this if there are no problematic commands
+    # subprocess.Popen(cmd_to_run, shell=True)
     
 def run_command(n_lines: list):
     exec_line = get_command(n_lines)
